function posMovedBLCP(pos)

% Get the values from the workspace
handles = evalin('base', 'handles');
options = evalin('base', 'options');
model = evalin('base', 'model');

% Delete the plots if they are present
if(isfield(handles, 'plots'))
    if(ishandle(handles.plots(1)))
          delete(handles.plots);
    end
end

% Calculate the bounding box
[minValues, maxValues] = getBoundingBoxVertices(model.vertices);

% Create the y map
yMap = linspace(minValues.y, maxValues.y, options.heightmapYResolution);
xMap = linspace(minValues.x, maxValues.x, options.heightmapXResolution);

% Get the current points
t1Pos = getPosition(handles.t1); t2Pos = getPosition(handles.t2);
c1Pos = getPosition(handles.c1); c2Pos = getPosition(handles.c2);
a1Pos = getPosition(handles.a1); a2Pos = getPosition(handles.a2);
s1Pos = getPosition(handles.s1); s2Pos = getPosition(handles.s2);


% Add them to row and column vectors
rowPoints= [t1Pos(1) t2Pos(1) c1Pos(1) c2Pos(1) a1Pos(1) a2Pos(1) s1Pos(1) s2Pos(1)];
colPoints = [t1Pos(2) t2Pos(2) c1Pos(2) c2Pos(2) a1Pos(2) a2Pos(2) s1Pos(2) s2Pos(2)];

% Compensate for the resolution
colPointsAdapted = options.heightmapYResolution - colPoints;

% Calculate the new 3D coordinates
coords.t1 = double([xMap(round(rowPoints(1))) yMap(round(colPointsAdapted(1))) 50-model.heightmap(round(colPoints(1)),round(rowPoints(1)))]);
coords.t2 = double([xMap(round(rowPoints(2))) yMap(round(colPointsAdapted(2))) 50-model.heightmap(round(colPoints(2)),round(rowPoints(2)))]);

coords.c1 = double([xMap(round(rowPoints(3))) yMap(round(colPointsAdapted(3))) 50-model.heightmap(round(colPoints(3)),round(rowPoints(3)))]);
coords.c2 = double([xMap(round(rowPoints(4))) yMap(round(colPointsAdapted(4))) 50-model.heightmap(round(colPoints(4)),round(rowPoints(4)))]);

coords.a1 = double([xMap(round(rowPoints(5))) yMap(round(colPointsAdapted(5))) 50-model.heightmap(round(colPoints(5)),round(rowPoints(5)))]);
coords.a2 = double([xMap(round(rowPoints(6))) yMap(round(colPointsAdapted(6))) 50-model.heightmap(round(colPoints(6)),round(rowPoints(6)))]);

coords.s1 = double([xMap(round(rowPoints(7))) yMap(round(colPointsAdapted(7))) 50-model.heightmap(round(colPoints(7)),round(rowPoints(7)))]);
coords.s2 = double([xMap(round(rowPoints(8))) yMap(round(colPointsAdapted(8))) 50-model.heightmap(round(colPoints(8)),round(rowPoints(8)))]);


% Get to the 3D object
figure(handles.patchMap);
hold on;

handles.plots = [];
handles.plots(end+1) = plot3(coords.t1(1), coords.t1(2), coords.t1(3), 'b*');
handles.plots(end+1) = text(coords.t1(1), coords.t1(2), coords.t1(3) + 1, 'T1');
handles.plots(end+1) = plot3(coords.t2(1), coords.t2(2), coords.t2(3), 'b*');
handles.plots(end+1) = text(coords.t2(1), coords.t2(2), coords.t2(3) + 1, 'T2');

handles.plots(end+1) = plot3(coords.c1(1), coords.c1(2), coords.c1(3), 'c*');
handles.plots(end+1) = text(coords.c1(1), coords.c1(2), coords.c1(3) + 1, 'C1');
handles.plots(end+1) = plot3(coords.c2(1), coords.c2(2), coords.c2(3), 'c*');
handles.plots(end+1) = text(coords.c2(1), coords.c2(2), coords.c2(3) + 1, 'C2');

handles.plots(end+1) = plot3(coords.a1(1), coords.a1(2), coords.a1(3), 'g*');
handles.plots(end+1) = text(coords.a1(1), coords.a1(2), coords.a1(3) + 1, 'A1');
handles.plots(end+1) = plot3(coords.a2(1), coords.a2(2), coords.a2(3), 'g*');
handles.plots(end+1) = text(coords.a2(1), coords.a2(2), coords.a2(3) + 1, 'A2');

handles.plots(end+1) = plot3(coords.s1(1), coords.s1(2), coords.s1(3), 'y*');
handles.plots(end+1) = text(coords.s1(1), coords.s1(2), coords.s1(3) + 1, 'S1');
handles.plots(end+1) = plot3(coords.s2(1), coords.s2(2), coords.s2(3), 'y*');
handles.plots(end+1) = text(coords.s2(1), coords.s2(2), coords.s2(3) + 1, 'S2');



assignin('base', 'handles', handles);
assignin('base', 'coords', coords);
end
