%% Main script

%% Instantiation
clear all; close all; clc;

% Add main function dir
addpath('Lib');

% Set parameters
readDir = 'C:\Users\Robin\Desktop\V7\Peerj\Matlab\Data';
saveDir = '';

patientName = {};
patient = [];
days = [];
ttDepth = [];
ccDepth = [];
ccDistance = [];
tcDistance = [];
ttDistance = [];
cleftWidth = [];
surgery = [];
%% Acquire Patients

% Get directory names
patientDirs = get_directory_names(readDir);

% Display information
disp(['The system has found ' num2str(length(patientDirs)) ' patients within the folder']);
%load('box2surgery.mat');
%% Loop through each patient and find its subfolders (scans)

for patientID = 1:length(patientDirs)
    % Get the fullpath
    patientDir = fullfile(readDir, patientDirs{patientID}, '/');
    
    % Get all the scans
    scans = dir(fullfile(patientDir, '*.mat'));
    
    % Display information
    disp(['Scanning patient folder: ' patientDirs{patientID} ', found ' num2str(length(scans)) ' scan folders']);
    
    %% Loop through each scan
    for scanID = 1:length(scans)
        
        disp(['    Loading file: ' scans(scanID).name]);
        
        
        
        % Get the full scan path
        scanPath = fullfile(patientDir, scans(scanID).name);
        
        % Load the actual data
        fContents = load(scanPath);
        if(isfield(fContents, 'fContents'))
            fc = fContents.fContents;
        else
            fc = fContents;
        end
        
        
        
        % Close all the images
        close all;
        
        % Create opcode mesh
        opMesh = opcodemesh(fc.model.vertices',fc.model.faces');
        
        % Plot the results
        figure('units','normalized','outerposition',[0 0 1 1])
        showPatch(fc.model.faces, fc.model.vertices, [0.7,0.7,0.7]);  camlight;
        hold on;
        
        % Check the c coordinates and create the TC1 and TC2 coordinate
        fc.coords = setTCPoint(fc.coords, opMesh, 5, 1000);
        
        
        
        plotAllCoordinates(fc.coords);
        
        % Create the estimation
        estimation = generateInitialLine(fc.coords, fc.model);
        plot3(estimation(:,1), estimation(:, 2), estimation(:, 3), 'linewidth',  4);
        
        % Create the search range
        searchLine = generateSearchLine(estimation, fc.model);
        plot3(searchLine.min(:,1), searchLine.min(:, 2), searchLine.min(:, 3), 'linewidth',  1, 'color', 'c');
        plot3(searchLine.max(:,1), searchLine.max(:, 2), searchLine.max(:, 3), 'linewidth',  1, 'color', 'c');
        
        k1 = dsearchn(estimation, [fc.coords.s1(1) fc.coords.s1(2)  fc.model.maxValues.z]) - 10;
        k2 = dsearchn(estimation, [fc.coords.s2(1) fc.coords.s2(2)  fc.model.maxValues.z]) + 10;
        
        % Get the alveolus
        alveolus_raw = generateAlveolusLine(estimation, searchLine, fc.model, opMesh);
        alveolus_smooth = smooth3Dline(alveolus_raw);
        
        plot3(alveolus_smooth(1:k1,1), alveolus_smooth(1:k1, 2), alveolus_smooth(1:k1, 3),'r' ,'linewidth',  2 );
        plot3(alveolus_smooth(k2:end,1), alveolus_smooth(k2:end, 2), alveolus_smooth(k2:end, 3),'r' ,'linewidth',  2 );
        
        
        %  fc.coords.t1 = alveolus_smooth(1,:);
        % fc.coords.t2 = alveolus_smooth(end,:);
        plot3([fc.coords.t1(1) fc.coords.t2(1)],[fc.coords.t1(2) fc.coords.t2(2)],[fc.coords.t1(3) fc.coords.t2(3)]);
        mTT = mean([fc.coords.t1; fc.coords.t2]);
        text(mTT(1), mTT(2), mTT(3) + 1,  "TT Distance");
        
        plot3([fc.coords.c1(1) fc.coords.c2(1)],[fc.coords.c1(2) fc.coords.c2(2)],[fc.coords.c1(3) fc.coords.c2(3)]);
        mCC = mean([fc.coords.c1; fc.coords.c2]);
        text(mCC(1), mCC(2), mCC(3) + 1,  "CC Distance");
        
        %% Find the most frontal point
        amean = mean([fc.coords.a1; fc.coords.a2]);
        fc.coords.frontal = alveolus_smooth(dsearchn(alveolus_smooth, amean), :);
        plot3(fc.coords.frontal(1), fc.coords.frontal(2), fc.coords.frontal(3), 'g*', 'linewidth', 3);
        
        %% Calculate the location on the TT line which has the shortest (perpendicular) distance to the most frontal point
        x1tt = fc.coords.t1;
        x2tt = fc.coords.t2;
        lineDirtt = (x2tt - x1tt) / norm(x2tt - x1tt);
        x0tt = fc.coords.frontal;
        
        vtt = x0tt - x1tt;
        dtt = dot(vtt, lineDirtt);
        stt = x1tt + dtt * lineDirtt ;
        
        x1cc = fc.coords.c1;
        x2cc = fc.coords.c2;
        lineDircc = (x2cc - x1cc) / norm(x2cc - x1cc);
        x0cc = fc.coords.frontal;
        
        vcc = x0cc - x1cc;
        dcc = dot(vcc, lineDircc);
        scc = x1cc + dcc * lineDircc;
        
        plot3(stt(1), stt(2), stt(3), 'c*', 'linewidth', 3);
        plot3(scc(1), scc(2), scc(3), 'k*', 'linewidth', 3);
        plot3([scc(1) fc.coords.frontal(1)],[scc(2) fc.coords.frontal(2)],[scc(3) fc.coords.frontal(3)]);
        
        %  text(mDepth(1), mDepth(2), mDepth(3) + 1,  "Depth");
        
        % Get the days from the date
        dateString =  scans(scanID).name;
        dateString(end-3:end) = [];
        dateParts = str2double(strsplit(dateString, '-'));
        
        
        patientName{end + 1} = patientDirs{patientID};
        patient(end+1) = patientID;
        days(end+1) = 365 * dateParts(1) + 30 * dateParts(2) + dateParts(3);
        ttDepth(end+1) = pdist2(stt, fc.coords.frontal);
        ccDepth(end+1) = pdist2(scc, fc.coords.frontal);
        ttDistance(end+1) = pdist2(fc.coords.t1, fc.coords.t2);
        ccDistance(end+1) = pdist2(fc.coords.c1, fc.coords.c2);
        tcDistance(end+1) = pdist2(fc.coords.tc1, fc.coords.tc2);
        cleftWidth(end+1) =  pdist2(fc.coords.s1(1:2), fc.coords.s2(1:2));
%         box2surgery2 = cell2mat(box2surgery);
%         temp = box2surgery(find(box2surgery2(:,1) == str2num(patientDirs{patientID})), 2);
%         
%         if(isempty(temp))
%             surgery(end + 1) = 9999;
%         else
%             surgery(end + 1) = temp{1};s
%             
%         end
        
                % Save this figure to the disk
                view(160, 20);
                answer = 'No';
                first = 1;
        
                while(~strcmp(answer, 'Yes'))
                    if(first == 0)
                    answer = questdlg('Alveolus correct?', ...
                        'Correct?', ...
                        'No','Yes','Yes');
                    else
                        first =  0;
                        answer = 'No';
                    end
        
                    if(strcmp(answer, 'No'))
                        %% Adaptions
                        r = struct;
                        r.leftPart = alveolus_smooth(1:k1,:);
                        r.rightPart = alveolus_smooth(k2:end,:);
        
                        % Conversion from 3D to 2D
                        yMap = linspace(fc.model.minValues.y, fc.model.maxValues.y, fc.options.heightmapYResolution);
                        xMap = linspace(fc.model.minValues.x, fc.model.maxValues.x, fc.options.heightmapXResolution);
        
                        % Search each coordinate in the map
                        xLocLeft = zeros(length(r.leftPart),1);
                        yLocLeft = zeros(length(r.leftPart),1);
                        for i = 1:length(r.leftPart)
                            yLocLeft(i) = dsearchn(yMap', r.leftPart(i,2));
                            xLocLeft(i) = dsearchn(xMap', r.leftPart(i,1));
                        end
                        yLocLeft = length(yMap) - yLocLeft;
        
                        % Search each coordinate in the map
                        xLocRight = zeros(length(r.rightPart),1);
                        yLocRight = zeros(length(r.rightPart),1);
                        for i = 1:length(r.rightPart)
                            yLocRight(i) = dsearchn(yMap', r.rightPart(i,2));
                            xLocRight(i) = dsearchn(xMap', r.rightPart(i,1));
                        end
                        yLocRight = length(yMap) - yLocRight;
        
                        hFig= figure('units','normalized','outerposition',[0 0 1 1]); imshow(fc.model.gMagHeightmap,[-0.5, 1]);
        
                        hold on;
                        pLeft = plot(xLocLeft, yLocLeft,'r*');
                        pRight = plot(xLocRight, yLocRight,'b*');
        
                        if(exist('editResult', 'var'))
                            delete editResult;
                        end
        
                        uicontrol('Parent',hFig,'Callback', {@newSpoint, 'l'}, 'Style','pushbutton','String','New S Point left','Units','normalized','Position',[0.0 0.6 0.1 0.05],'Visible','on');
                        uicontrol('Parent',hFig,'Callback', {@newSpoint, 'r'}, 'Style','pushbutton','String','New S Point right','Units','normalized','Position',[0.0 0.5 0.1 0.05],'Visible','on');
                        uicontrol('Parent',hFig,'Callback', {@truncateULCPLine, 'l'}, 'Style','pushbutton','String','Truncate line left','Units','normalized','Position',[0.0 0.4 0.1 0.05],'Visible','on');
                        uicontrol('Parent',hFig,'Callback', {@truncateULCPLine, 'r'}, 'Style','pushbutton','String','Truncate line right','Units','normalized','Position',[0.0 0.3 0.1 0.05],'Visible','on');
                        uicontrol('Parent',hFig,'Callback', {@editULCPLine, 'l'}, 'Style','pushbutton','String','Edit line left','Units','normalized','Position',[0.0 0.2 0.1 0.05],'Visible','on');
                        uicontrol('Parent',hFig,'Callback', {@editULCPLine, 'r'}, 'Style','pushbutton','String','Edit line right','Units','normalized','Position',[0.0 0.1 0.1 0.05],'Visible','on');
        
        
                        waitfor(hFig);
                    end
        
        
        
                end
        
        save(fullfile(saveDir, [patientDirs{patientID} '-' scans(scanID).name '.mat' ]));
        saveas(gcf, fullfile(saveDir, [patientDirs{patientID} '-' scans(scanID).name '.png' ]));
        
    end
end

%%
allResults = cell(length(days),10);
allResults(:,1) = patientName;
allResults(:,2) = num2cell(patient);
allResults(:,3) = num2cell(days);
allResults(:,4) = num2cell(ttDepth);
allResults(:,5) = num2cell(ccDepth);
allResults(:,6) = num2cell(ccDistance);
allResults(:,7) = num2cell(ttDistance);
allResults(:,8) = num2cell(cleftWidth);
%allResults(:,9) = num2cell(surgery);
allResults(:,10) = num2cell(tcDistance);



